Index: src/objects.h |
diff --git a/src/objects.h b/src/objects.h |
index abd38aa61e445b68627b522d7059747125701146..e980c728222cba633dca213f9106b26e4b4d345d 100644 |
--- a/src/objects.h |
+++ b/src/objects.h |
@@ -881,10 +881,10 @@ class FixedArrayBase; |
class GlobalObject; |
class ObjectVisitor; |
class StringStream; |
// We cannot just say "class Type;" if it is created from a template... =8-? |
template<class> class TypeImpl; |
class HeapTypeConfig; |
-typedef TypeImpl<HeapTypeConfig> Type; |
+typedef TypeImpl<HeapTypeConfig> HeapType; |
// A template-ized version of the IsXXX functions. |
@@ -9379,8 +9379,8 @@ class Cell: public HeapObject { |
class PropertyCell: public Cell { |
public: |
// [type]: type of the global property. |
- Type* type(); |
- void set_type(Type* value, WriteBarrierMode mode = UPDATE_WRITE_BARRIER); |
+ HeapType* type(); |
+ void set_type(HeapType* value, WriteBarrierMode mode = UPDATE_WRITE_BARRIER); |
// [dependent_code]: dependent code that depends on the type of the global |
// property. |
@@ -9395,8 +9395,8 @@ class PropertyCell: public Cell { |
// Computes the new type of the cell's contents for the given value, but |
// without actually modifying the 'type' field. |
- static Handle<Type> UpdatedType(Handle<PropertyCell> cell, |
- Handle<Object> value); |
+ static Handle<HeapType> UpdatedType(Handle<PropertyCell> cell, |
+ Handle<Object> value); |
void AddDependentCompilationInfo(CompilationInfo* info); |
@@ -881,10 +881,10 @@ class FixedArrayBase; |
class ObjectVisitor; |
class StringStream; |
-// We cannot just say "class Type;" if it is created from a template... =8-? |
+// We cannot just say "class HeapType;" if it is created from a template... =8-? |
template<class> class TypeImpl; |
class HeapTypeConfig; |